View source: R/timeROC_archived.R
| timeROC | R Documentation |
Computes time-dependent AUC for survival models using inverse probability of censoring weighting (IPCW).
timeROC(
T,
delta,
marker,
other_markers = NULL,
cause,
weighting = "marginal",
times,
ROC = TRUE,
iid = FALSE
)
T |
Vector of observed failure times. |
delta |
Vector of status indicators: |
marker |
Vector of marker values. |
other_markers |
Optional matrix of additional markers associated with
the censoring mechanism. Default is |
cause |
The value of |
weighting |
Weighting technique for IPCW. One of |
times |
Vector of time points at which to compute the time-dependent AUC. |
ROC |
Logical; if |
iid |
Logical; if |
This function is a verbatim copy from the timeROC package (v0.4) by Paul Blanche and Mickaƫl Foucher, which was archived on CRAN in 2024 (https://cran.r-project.org/package=timeROC). It is included here without modification to ensure continued functionality of the CalibrationCurves package after the dependency was removed.
An object of class "ipcwcompetingrisksROC" (with competing
risks) or "ipcwsurvivalROC" (without competing risks), containing:
AUC: vector of AUC values for each time point.
TP, FP: (if ROC = TRUE) matrices of true and
false positive fractions.
times: the (ordered) input time points.
n: number of observations.
Stats: matrix with case/control/censoring counts per time point.
weights: IPCW weight object.
computation_time: elapsed computation time.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.